import { ServiceFactory } from "app/services/service-factory";
import { decodeHtml } from "../../../util/util";
import { CalculatorType, MacroRugoRemous } from "jalhyd";
import { SelectField } from "./select-field";
import { FormulaireNode } from "../formulaire-node";

// Courbe de remous dans une passe à macro-rugo.
export class SelectFieldTargetPam extends SelectField {
    constructor(parent: FormulaireNode) {
        super(parent);
        this._associatedProperty = MacroRugoRemous.NubMacroRugoProp;
        this._messageWhenEmpty = "INFO_MACRORUGOREMOUS_CREATE_PAM_FIRST";
    }

    protected populate() {

        const fs = ServiceFactory.formulaireService;

        // find all rock-ramp fishpass forms
        const macroForms: any[] = fs.formulaires.filter((element, index, self) =>
            element.calculatorType === CalculatorType.MacroRugo
        );
        for (const cn of macroForms) {
            const calc = cn.calculatorName;
            this.addEntry(this.createOrGetEntry(this._entriesBaseId + cn.uid, cn.uid, decodeHtml(calc)));
        }
    }

    protected initSelectedValue() {
        const mrr = (this.nub as MacroRugoRemous).nubMacroRugo;
        if (mrr !== undefined) {
            this.setValueFromId(this._entriesBaseId + mrr.uid);
        }
    }

    public updateLocalisation() {
        // do not override localisation done in populate()
        // ie. avoid what is done by SelectField.updateLocalisation()
    }
}
